--[[ ML.events ]]

function ML.events.VariablesLoaded()
	if( type( mAutoLootVariables ) ~= "table" )then
		mAutoLootVariables = ML.DefaultConfig;
		ML.Message( 'First start! Set default config values.' );
	else
		for k, v in pairs( ML.DefaultConfig ) do
			if( mAutoLootVariables[k] == nil ) then mAutoLootVariables[k] = v; end;
		end;
	end;
	SaveVariables("mAutoLootVariables");
	
	--[[ slash commands ]]
	Sol.config.CreateSlashCommand("ml",ShowHideMainWindow);

	ML.ui.StartMessage();
	SetInstanceLevel( ML.IL[ mAutoLootVariables.InstanceLevel ] );
	ML.utils.SetLootMethod();
	
	if( ML.tools.fileExists("Interface/AddOns/mLoot/mAutoLootStoredVariables.lua") )then
		dofile("Interface/AddOns/mLoot/mAutoLootStoredVariables.lua");
		ML.Message( "Считывание сохраненного файла конфигурации!" );
		for k, v in pairs( mAutoLootStoderVariables ) do
			mAutoLootVariables[ k ] = v;
		end;
	end;
	
	if( not mAutoLootVariables.GarbageList['Version'] )or( mAutoLootVariables.GarbageList['Version'] ~= ML.ListVersion )then
		ML.Message( "|cffFF0000ВНИМАНИЕ!!!|r" );
		ML.Message( "Формат дроп листа неверен, пожалуйста очистите дроп лист, используя специальную функцию в выпадающем меню кнопки у миникарты!" );
	end;
	if( not mAutoLootVariables.SellList['Version'] )or( mAutoLootVariables.SellList['Version'] ~= ML.ListVersion )then
		ML.Message( "|cffFF0000ВНИМАНИЕ!!!|r" );
		ML.Message( "Формат листа продаж неверен, пожалуйста очистите лист продаж, используя специальную функцию в выпадающем меню кнопки у миникарты!" );
	end;
	if( not mAutoLootVariables.MaskedGarbageListVersion )or( mAutoLootVariables.MaskedGarbageListVersion ~= ML.ListVersion )then
		ML.Message( "|cffFF0000ВНИМАНИЕ!!!|r" );
		ML.Message( "Формат листа масок выбрасываемых предметов неверен, пожалуйста очистите лист масок выбрасываемых предметов, используя специальную функцию в выпадающем меню кнопки у миникарты!" );
	end;
		
	BagTitleText:ClearAllAnchors();
	BagTitleText:SetAnchor("TOPLEFT", "TOPLEFT", BagFrame, 65, 7);
	
	if( mAutoLootVariables.Items == nil )then
		local fn, err = loadfile("interface/addons/mloot/code/item.lua")
		if( fn )then
			mAutoLootVariables.Items = fn()
		end;
	end;
	
	ML.eb.OnHide( _G[ ML.eb.FrameName ] );
end;

function ML.events.OnShow(frame)
	MLFrame_Title:SetText( ML.Name );
	MLFrame_Version:SetText( ML.Version );
end;

function ML.events.OnMouseDown(this)
	this:StartMoving("TOPLEFT");
end;

function ML.events.OnMouseUp(this)
	this:StopMovingOrSizing();
end;

function ML.events.OnEvent(event)
	--[[ 
		this:RegisterEvent("STORE_OPEN");
		this:RegisterEvent("BOOTY_SHOW");
	]]
	if( event == "VARIABLES_LOADED" )then
		ML.events.VariablesLoaded();
	end;

	if( event == "BOOTY_SHOW" )then
		ML.utils.looting();
	end;
	
	if( event == "PARTY_MEMBER_CHANGED" )then
		SetInstanceLevel( ML.IL[ mAutoLootVariables.InstanceLevel ] );
		ML.utils.SetLootMethod();
	end;
	
	if( event == "CHAT_MSG_SYSTEM_GET" )then
		ML.utils.GarbageDrop();
	end;
	
	if( event == "STORE_OPEN" )then
		ML.utils.AutoSell();
	end;
end;

function ML.events.OnLoadMinimapButton()
end;

function ML.events.SetButtonTextures()
	local normalTexture = MLMinimapButton:GetNormalTexture();
	local pushedTexture = MLMinimapButton:GetPushedTexture();
end

function ML.events.OnUpdateMinimapButton( frame )
end;

function ML.events.ShowHint( frame )
	GameTooltip:SetOwner( frame, "ANCHOR_LEFT", 4, 0 );
	GameTooltip:SetText( ML.Name, 1, 1, 1 );
	GameTooltip:AddSeparator();
	
	if( mAutoLootVariables.Enabled )then
		GameTooltip:AddLine( "   |cff00FF00ВКЛЮЧЕН!|r" );
	else
		GameTooltip:AddLine( "   |cffFF0000ВЫКЛЮЧЕН!|r" );
	end;
	
	if( mAutoLootVariables.AutoLootElit )then
		GameTooltip:AddLine( "   Автолут с элиток: " .. ML.consts["Enable"] );
	else
		GameTooltip:AddLine( "   Автолут с элиток: " .. ML.consts["Disable"] );
	end;
	
	if( mAutoLootVariables.AutoLootBoss )then
		GameTooltip:AddLine( "   Автолут с боссов: " .. ML.consts["Enable"] );
	else
		GameTooltip:AddLine( "   Автолут с боссов: " .. ML.consts["Disable"] );
	end;

	GameTooltip:AddLine( "   Подбор предметов: " .. ML.Qualities[ mAutoLootVariables.Quality ] );

	if( mAutoLootVariables.AutoSell )then
		GameTooltip:AddLine( "   Автопродажа: " .. ML.consts["Enable"] );
	else
		GameTooltip:AddLine( "   Автопродажа: " .. ML.consts["Disable"] );
	end;

	if( mAutoLootVariables.AutoGuildDonate )then
		GameTooltip:AddLine( "   Автовзнос в гильдию: " .. ML.consts["Enable"] );
	else
		GameTooltip:AddLine( "   Автовзнос в гильдию: " .. ML.consts["Disable"] );
	end;
	
	GameTooltip:AddSeparator();
	
	GameTooltip:AddLine( "   Сложность подземелий: " .. ML.InstanceLevel[ mAutoLootVariables.InstanceLevel ] );
	GameTooltip:AddLine( "   Трофеи группы: " .. ML.RollType[ mAutoLootVariables.RollType ] );
	GameTooltip:AddLine( "   Лут группы: " .. ML.GroupLoot[ mAutoLootVariables.GroupLoot ] );
	GameTooltip:AddLine( "   Лут группы до: " .. ML.Qualities[ mAutoLootVariables.GroupLootQuality ] );

	GameTooltip:AddLine( "Левая кнопка мыши открыть окно настроек", 0, 0.75, 0.95 );
	GameTooltip:AddLine( UI_MINIMAPBUTTON_MOVE, 0, 0.75, 0.95 );
	GameTooltip:Show();
end;

function ML.events.HideHint( frame )
	GameTooltip:Hide()
end;

function ML.events.ShowHideMainWindow()
	if( MLFrame:IsVisible() )then
		MLFrame:Hide();
	else
		MLFrame:Show();
	end;
end;

function ML.events.OnClickMinimapButton(key)
	if( key == "LBUTTON" )then 
		ML.events.ShowHideMainWindow();
	else
		ML.utils.reloadGabageList();
	end;
end;



-- /run dofile("Interface/AddOns/mLoot/code/events.lua");