--[[ ML.tools ]]

function ML.tools.fileExists( fileName )
	local func, err=loadfile( fileName );
	local lookerr = "cannot open " .. fileName .. ": No such file or directory";
	if( not err )then
		return true, nil;
	elseif( err and string.find( tostring( err ), lookerr ) == nil )then
		ML.Message( err );
		return false, err;
	end
	return false, err;
end;

function ML.tools.ParseItemLink( itemLink )
	local itemIDdec = tonumber(string.sub(itemLink, 8, 12), 16);  -- Convert to decimal
	local itemType, itemIDhex, itemPlus, itemNamecolor = string.match(itemLink, "|H(.+):(%x+)%s+%x+%s+(%x+).+|h(.+)|h");
	ML.Message( itemType .." ".. itemIDhex .." ".. itemPlus .." ".. itemNamecolor );
	local itemLink = string.format("|H%s:%s|h%s|r|h", itemType, itemIDhex, "");
	--DEFAULT_CHAT_FRAME:AddMessage(itemLink);
	return itemIDdec, itemIDhex, itemPlus, itemLink, itemNamecolor
end;

--[[ |Hitem:<id> <bind type> <runes><plus><tiering><max dura> <stats>x7 <current dura> <hash>|h|cff<color>[<name>]|r|h ]]
function ML.tools.itemID( link )
    if( not link )then return nil; end;
    local id = link:match("^|H.-:([0-9a-f]+)");
	return Sol.math.HexToDec( id );
end

function ML.tools.itemName( link )
    if( not link )then return nil; end;
    local name = link:match("|h(.+)|h") or "";
	if( MUIChatFrame ~= nil )then
		return name:sub( 12, -14 );
	else
		return name:sub( 12, -2 );
	end;
end

function ML.tools.GetItemType( bagSlotID )
	local _,a,_,_,_,_ = GetBagItemInfo( bagSlotID );
end;

function ML.tools.LinkText( link )
	local itemType, itemIdhex, itemPlus, itemNamecolor = string.match(link, "|H(.+):(%x+)%s+%x+%s+(%x+).+|h(.+)|h");
	ML.Message( itemType..' '..itemIdhex..' '..itemPlus..' '..itemNamecolor );
	return link:match("^|H.-:(.+)|r|h");
end;

function ML.tools.AddGarbage( link )
	local itemID = ML.tools.itemID( link );
	ML.Message( link .. ML.cc .. " (" .. tostring( itemID ) .. ") добавлен в |cff990000дроп лист|r" .. ML.cc .. "." );
	mAutoLootVariables.GarbageList[itemID] = link;
end;

function ML.tools.DeleteGarbage( link )
	local newGarbageList = {};
	local itemID = ML.tools.itemID( link );
	for k, v in pairs( mAutoLootVariables.GarbageList )do
		if( k ~= itemID )then newGarbageList[ k ] = v; end;
	end;
	mAutoLootVariables.GarbageList = newGarbageList;
	ML.Message( link .. ML.cc .. " (" .. tostring( itemID ) .. ") удален из |cff990000дроп листа|r" .. ML.cc .. "." );
end;

function ML.tools.AddSellItem( link )
	local itemID = ML.tools.itemID( link );
	ML.Message( link .. ML.cc .. " (" .. tostring( itemID ) .. ") добавлен в |cff009900список продаваемых предметов|r" .. ML.cc .. "." );
	mAutoLootVariables.SellList[ itemID ] = link;
end;

function ML.tools.DeleteSellItem( link )
	local newSellList = {};
	local itemID = ML.tools.itemID( link );
	for k, v in pairs( mAutoLootVariables.SellList )do
		if( k ~= itemID )then newSellList[ k ] = v; end;
	end;
	mAutoLootVariables.SellList = newSellList;
	ML.Message( link .. ML.cc .. " (" .. tostring( itemID ) .. ") удален из |cff009900листа продаж|r" .. ML.cc .. "." );
end;

function ML.tools.AddDonateItem( link )
	local itemID = ML.tools.itemID( link );
	ML.Message( link .. ML.cc .. " (" .. tostring( itemID ) .. ") добавлен в |cffFFAA00список взносов в гильдию|r" .. ML.cc .. "." );
	mAutoLootVariables.DonateList[ itemID ] = link;
end;

function ML.tools.DeleteDonateItem( link )
	local newDonateList = {};
	local itemID = ML.tools.itemID( link );
	for k, v in pairs( mAutoLootVariables.DonateList )do
		if( k ~= itemID )then newDonateList[ k ] = v; end;
	end;
	mAutoLootVariables.DonateList = newDonateList;
	ML.Message( link .. ML.cc .. " (" .. tostring( itemID ) .. ") удален из |cffFFAA00листа взносов в гильдию|r" .. ML.cc .. "." );
end;

function MLClearDropList( arg )
	mAutoLootVariables.GarbageList = {};
	mAutoLootVariables.GarbageList["Version"] = ML.ListVersion;
	ML.Message( "Дроп лист очищен. Установлена версия дроп листа " .. tostring( ML.ListVersion ) );
end;

function MLClearSellList( arg )
	mAutoLootVariables.SellList = {};
	mAutoLootVariables.SellList["Version"] = ML.ListVersion;
	ML.Message( "Лист продаж очищен. Установлена версия листа продаж " .. tostring( ML.ListVersion ) );
end;

function MLClearDropMasksList( arg )
	mAutoLootVariables.MaskedGarbageList = {};
	mAutoLootVariables.MaskedGarbageListVersion = ML.ListVersion;
	ML.Message( "Лист масок выбрасываемых предметов. Установлена версия листа масок выбрасываемых предметов " .. tostring( ML.ListVersion ) );
end;

function ML.tools.IsItemInPassList( itemName )
	for n = 1, #mAutoLootVariables.PassList do
		if( mAutoLootVariables.PassList[ n ] == itemName )then return true; end;
	end;
	return false;
end;

function ML.tools.IsItemInGreedList( itemName )
	for n = 1, #mAutoLootVariables.GreedList do
		if( mAutoLootVariables.GreedList[ n ] == itemName )then return true; end;
	end;
	return false;
end;

function ML.tools.IsItemInRollList( itemName )
	for n = 1, #mAutoLootVariables.RollList do
		if( mAutoLootVariables.RollList[ n ] == itemName )then return true; end;
	end;
	return false;
end;

function MLDeleteDropMask( id )
	local newList = {};
	local i = tonumber( id );
	for n = 1, #mAutoLootVariables.MaskedGarbageList do
		if( n ~= i )then newList[ #newList + 1 ] = mAutoLootVariables.MaskedGarbageList[ n ]; end;
	end;
	mAutoLootVariables.MaskedGarbageList = newList;
	ML.ui.redrawDropMasksList( MLConfigFramePageBar2_ScrollBar );
end;

function ML.tools.DeleteDropMask( id )
	local i = id + MLConfigFramePageBar2_ScrollBar:GetValue();
	local _mask = mAutoLootVariables.MaskedGarbageList[ i ]["mask"] .. " [" .. mAutoLootVariables.MaskedGarbageList[ i ]["range"]["min"] .. "-" .. mAutoLootVariables.MaskedGarbageList[ i ]["range"]["max"] .. "]";
	ML.ui.Dialog( 'Подтверждение', 'Вы действительно хотите удалить маску "' .. _mask .. '"?', i, 'MLDeleteDropMask' );
end;

function MLDeleteException( id )
	local newList = {};
	local i = tonumber( id );
	for n = 1, #mAutoLootVariables.ExceptionsList do
		if( n ~= i )then newList[ #newList + 1 ] = mAutoLootVariables.ExceptionsList[ n ]; end;
	end;
	mAutoLootVariables.ExceptionsList = newList;
	ML.ui.redrawExceptionList( MLConfigFramePageBar3_ScrollBar );
end;

function ML.tools.DeleteException( id )
	local i = id + MLConfigFramePageBar2_ScrollBar:GetValue();
	ML.ui.Dialog( 'Подтверждение', 'Вы действительно хотите удалить исключение "' .. mAutoLootVariables.ExceptionsList[ i ] .. '"?', i, 'MLDeleteException' );
end;

function ML.tools.ChangeCase( str, _upper )
	local stChars = {
		[1]  = { "А", "а" },
		[2]  = { "Б", "б" },
		[3]  = { "В", "в" },
		[4]  = { "Г", "г" },
		[5]  = { "Д", "д" },
		[6]  = { "Е", "е" },
		[7]  = { "Ё", "ё" },
		[8]  = { "Ж", "ж" },
		[9]  = { "З", "з" },
		[10] = { "И", "и" },
		[11] = { "Й", "й" },
		[12] = { "К", "к" },
		[13] = { "Л", "л" },
		[14] = { "М", "м" },
		[15] = { "Н", "н" },
		[16] = { "О", "о" },
		[17] = { "П", "п" },
		[18] = { "Р", "р" },
		[19] = { "С", "с" },
		[20] = { "Т", "т" },
		[21] = { "У", "у" },
		[22] = { "Ф", "ф" },
		[23] = { "Х", "х" },
		[24] = { "Ц", "ц" },
		[25] = { "Ч", "ч" },
		[26] = { "Ш", "ш" },
		[27] = { "Щ", "щ" },
		[28] = { "Ъ", "ъ" },
		[29] = { "Ы", "ы" },
		[30] = { "Ь", "ь" },
		[31] = { "Э", "э" },
		[32] = { "Ю", "ю" },
		[33] = { "Я", "я" },
	};
	if( _upper ~= nil )and( _upper == true )then
		str = string.upper( str );
		for n = 1, 33 do 
			str = string.gsub( str, stChars[ n ][ 2 ], stChars[ n ][ 1 ] );
		end;
	else
		str = string.lower( str );
		for n = 1, 33 do 
			str = string.gsub( str, stChars[ n ][ 1 ], stChars[ n ][ 2 ] );
		end;
	end;
	return str;
end;

-- /run dofile("Interface/AddOns/mLoot/code/tools.lua");